# DotEnvHub Tasks


## .Env Selector Container
- Navigation j,k?
## Exporter Interaction Container

## Modal Screens

## Config File
- Last copied .env content?

# Argparse Funktionen
- ohne Args: Tui App

- Argumente / Flags
  - Import: Pfad zur datei
    - name: target name
  - export: file, path, shells?
    - name der datei unter env-dirs folder

+ console Log?

# Generell
- Tests
- Docs
- Bindings
